package nl.kallestruik.darena.arenas

import nl.kallestruik.darena.types.arena.ArenaLoadout
import nl.kallestruik.darena.types.arena.ArenaSpawn
import nl.kallestruik.darena.util.ConfigHelper
import java.io.File

data class ArenaConfig(
    var name: String = "[Missing name]",
    var spawns: List<ArenaSpawn> = emptyList(),
    var spectatorSpawn: ArenaSpawn = ArenaSpawn("default", 0.0, 100.0, 0.0, 0.0F, 0.0F, "default"),
    var loadouts: List<ArenaLoadout> = emptyList(),
) {

    companion object {
        fun load(file: File): ArenaConfig {
            val config = ConfigHelper.getOrCreateConfig(file, "template/arena.yml")
            val arenaConfig = ArenaConfig()

            if (config.contains("name"))
                arenaConfig.name = config.getString("name")!!

            if (config.contains("spawns"))
                arenaConfig.spawns = ArenaSpawn.loadList(config.getConfigurationSection("spawns")!!)

            if (config.contains("spectatorSpawn"))
                arenaConfig.spectatorSpawn = ArenaSpawn.load(config.getConfigurationSection("spectatorSpawn")!!)

            if (config.contains("loadouts"))
                arenaConfig.loadouts = ArenaLoadout.loadList(config.getConfigurationSection("loadouts")!!)

            return arenaConfig
        }
    }
}
